@@ -12,6 +12,11 @@ try:
 except:
     data = json.load(open(dirs + '//wc_data//data.json', encoding='ansi'))
 
+try:
+    data_mingyan = json.load(open('data_mingyan.json', encoding='utf8'))
+except:
+    data_mingyan = json.load(open(dirs + '//wc_data//data_mingyan.json', encoding='utf8'))
+
 
 def generator(title, lenth=800):
     body = ""
@@ -38,3 +43,14 @@ def make_and_write(title, lenth = 800):
     with open(title + '.txt', 'w+') as f:
         f.write(composition)
         f.close()
+
+def only(type_, lenth = 800):
+    if type_ == 'famous_quotes':
+        body = ''
+        while len(body) < lenth:
+            num = random.randint(0, 100)
+            if num < 10:
+                body += "\r\n"
+            else:
+                body += random.choice(data_mingyan)
+        return body
